@@ -34,9 +34,8 @@ fn main() {
     let surface = cairo::ImageSurface::create(cairo::Format::ARgb32, width, height).unwrap();
     let cr = cairo::Context::new(&surface);
     renderer
-        .render_element_to_viewport(
+        .render_document(
             &cr,
-            None,
             &cairo::Rectangle {
                 x: 0.0,
                 y: 0.0,
