@@ -227,7 +227,7 @@ impl Loader {
     /// ```
     pub fn read_path<P: AsRef<Path>>(self, path: P) -> Result<SvgHandle, LoadingError> {
         let file = gio::File::new_for_path(path);
-        self.read_file(&file, None)
+        self.read_file(&file, None::<&Cancellable>)
     }
 
     /// Reads an SVG file from a `gio::File`.
@@ -242,21 +242,16 @@ impl Loader {
     /// use librsvg::Loader;
     ///
     /// let svg_handle = Loader::new()
-    ///     .read_file(&gio::File::new_for_path("hello.svg"), None)
+    ///     .read_file(&gio::File::new_for_path("hello.svg"), None::<&gio::Cancellable>)
     ///     .unwrap();
     /// ```
-    pub fn read_file<'a, P: Into<Option<&'a Cancellable>>>(
+    pub fn read_file<F: IsA<gio::File>, P: IsA<Cancellable>>(
         self,
-        file: &gio::File,
-        cancellable: P,
+        file: &F,
+        cancellable: Option<&P>,
     ) -> Result<SvgHandle, LoadingError> {
-        let cancellable = cancellable.into();
-
-        let cancellable_clone = cancellable.clone();
-
         let stream = file.read(cancellable)?;
-
-        self.read_stream(&stream, Some(&file), cancellable_clone)
+        self.read_stream(&stream, Some(file), cancellable)
     }
 
     /// Reads an SVG stream from a `gio::InputStream`.
@@ -271,14 +266,16 @@ impl Loader {
     /// URL where this SVG got loaded from.
     ///
     /// The `cancellable` can be used to cancel loading from another thread.
-    pub fn read_stream<'a, P: Into<Option<&'a Cancellable>>, S: IsA<gio::InputStream>>(
+    pub fn read_stream<S: IsA<gio::InputStream>, F: IsA<gio::File>, P: IsA<Cancellable>>(
         self,
         stream: &S,
-        base_file: Option<&gio::File>,
-        cancellable: P,
+        base_file: Option<&F>,
+        cancellable: Option<&P>,
     ) -> Result<SvgHandle, LoadingError> {
+        let base_file = base_file.map(|f| f.as_ref());
+
         let base_url = if let Some(base_file) = base_file {
-            Some(url_from_file(&base_file)?)
+            Some(url_from_file(base_file)?)
         } else {
             None
         };
@@ -290,7 +287,7 @@ impl Loader {
         Ok(SvgHandle(Handle::from_stream(
             &load_options,
             stream,
-            cancellable.into(),
+            cancellable.map(|c| c.as_ref()),
         )?))
     }
 }
