@@ -1,5 +1,3 @@
-use std::cell::Cell;
-
 // This is configurable at runtime
 const DEFAULT_DPI_X: f64 = 90.0;
 const DEFAULT_DPI_Y: f64 = 90.0;
@@ -7,36 +5,32 @@ const DEFAULT_DPI_Y: f64 = 90.0;
 static mut DPI_X: f64 = DEFAULT_DPI_X;
 static mut DPI_Y: f64 = DEFAULT_DPI_Y;
 
-#[derive(Debug, Clone, Default)]
+#[derive(Debug, Copy, Clone, Default)]
 pub struct Dpi {
-    x: Cell<f64>,
-    y: Cell<f64>,
+    x: f64,
+    y: f64,
 }
 
 impl Dpi {
-    pub fn x(&self) -> f64 {
-        if self.x.get() <= 0.0 {
-            unsafe { DPI_X }
-        } else {
-            self.x.get()
-        }
+    pub fn new(x: f64, y: f64) -> Dpi {
+        Dpi { x, y }
     }
 
-    pub fn set_x(&self, dpi_x: f64) {
-        self.x.set(dpi_x)
+    pub fn x(&self) -> f64 {
+        if self.x <= 0.0 {
+            unsafe { DPI_X }
+        } else {
+            self.x
+        }
     }
 
     pub fn y(&self) -> f64 {
-        if self.y.get() <= 0.0 {
+        if self.y <= 0.0 {
             unsafe { DPI_Y }
         } else {
-            self.y.get()
+            self.y
         }
     }
-
-    pub fn set_y(&self, dpi_y: f64) {
-        self.y.set(dpi_y)
-    }
 }
 
 #[no_mangle]
