@@ -1,4 +1,4 @@
-use std::cell::UnsafeCell;
+use std::cell::RefCell;
 use std::collections::HashMap;
 use std::f64;
 
@@ -62,7 +62,7 @@ pub struct FilterContext {
     /// Surfaces of the previous filter primitives by name.
     previous_results: HashMap<String, FilterOutput>,
     /// The background surface. Computed lazily.
-    background_surface: UnsafeCell<Option<Result<SharedImageSurface, FilterError>>>,
+    background_surface: RefCell<Option<Result<SharedImageSurface, FilterError>>>,
     /// The filter effects region.
     effects_region: BoundingBox,
     /// Whether the currently rendered filter primitive uses linear RGB for color operations.
@@ -157,7 +157,7 @@ impl FilterContext {
             source_surface,
             last_result: None,
             previous_results: HashMap::new(),
-            background_surface: UnsafeCell::new(None),
+            background_surface: RefCell::new(None),
             effects_region: filter.compute_effects_region(
                 computed_from_node_being_filtered,
                 draw_ctx,
@@ -201,22 +201,22 @@ impl FilterContext {
     pub fn background_image(
         &self,
         draw_ctx: &DrawingCtx,
-    ) -> Result<&SharedImageSurface, FilterError> {
+    ) -> Result<SharedImageSurface, FilterError> {
         {
             // At this point either no, or only immutable references to background_surface exist, so
             // it's ok to make an immutable reference.
-            let bg = unsafe { &*self.background_surface.get() };
+            let bg = self.background_surface.borrow();
 
             // If background_surface was already computed, return the immutable reference. It will
             // get bound to the &self lifetime by the function return type.
-            if let Some(result) = bg.as_ref() {
-                return result.as_ref().map_err(|&s| s);
+            if let Some(ref result) = *bg {
+                return result.clone();
             }
         }
 
         // If we got here, then background_surface hasn't been computed yet. This means there are
         // no references to it and we can create a mutable reference.
-        let bg = unsafe { &mut *self.background_surface.get() };
+        let mut bg = self.background_surface.borrow_mut();
 
         *bg = Some(
             cairo::ImageSurface::create(
@@ -232,7 +232,7 @@ impl FilterContext {
         );
 
         // Return the only existing reference as immutable.
-        bg.as_ref().unwrap().as_ref().map_err(|&s| s)
+        bg.as_ref().unwrap().as_ref().map(|surf| surf.clone()).map_err(|&s| s)
     }
 
     /// Returns the surface containing the background image snapshot alpha.
@@ -381,7 +381,6 @@ impl FilterContext {
                 .map(FilterInput::StandardInput),
             Input::BackgroundImage => self
                 .background_image(draw_ctx)
-                .map(Clone::clone)
                 .map(FilterInput::StandardInput),
             Input::BackgroundAlpha => self
                 .background_alpha(draw_ctx, self.effects_region().rect.unwrap().into())
