@@ -2,7 +2,7 @@ use cairo::{self, ImageSurface};
 use cssparser;
 
 use crate::drawing_ctx::DrawingCtx;
-use crate::node::{NodeResult, NodeTrait, RsvgNode};
+use crate::node::{CascadedValues, NodeResult, NodeTrait, RsvgNode};
 use crate::property_bag::PropertyBag;
 use crate::surface_utils::shared_surface::{SharedImageSurface, SurfaceType};
 
@@ -14,10 +14,10 @@ pub struct Flood {
     base: Primitive,
 }
 
-impl Flood {
+impl Default for Flood {
     /// Constructs a new `Flood` with empty properties.
     #[inline]
-    pub fn new() -> Flood {
+    fn default() -> Flood {
         Flood {
             base: Primitive::new::<Self>(),
         }
@@ -25,9 +25,11 @@ impl Flood {
 }
 
 impl NodeTrait for Flood {
+    impl_node_as_filter!();
+
     #[inline]
-    fn set_atts(&self, node: &RsvgNode, pbag: &PropertyBag<'_>) -> NodeResult {
-        self.base.set_atts(node, pbag)
+    fn set_atts(&mut self, parent: Option<&RsvgNode>, pbag: &PropertyBag<'_>) -> NodeResult {
+        self.base.set_atts(parent, pbag)
     }
 }
 
@@ -46,7 +48,7 @@ impl Filter for Flood {
             ctx.source_graphic().height(),
         )?;
 
-        let cascaded = node.get_cascaded_values();
+        let cascaded = CascadedValues::new_from_node(node);
         let values = cascaded.get();
 
         let color = match values.flood_color.0 {
@@ -75,7 +77,7 @@ impl Filter for Flood {
         }
 
         Ok(FilterResult {
-            name: self.base.result.borrow().clone(),
+            name: self.base.result.clone(),
             output: FilterOutput {
                 surface: SharedImageSurface::new(output_surface, SurfaceType::SRgb)?,
                 bounds,
