@@ -356,6 +356,8 @@ impl PathBuilder {
     }
 
     pub fn to_cairo(&self, cr: &cairo::Context) -> Result<(), cairo::Status> {
+        assert!(!self.empty());
+
         for s in &self.path_commands {
             s.to_cairo(cr);
         }
@@ -376,6 +378,10 @@ impl PathBuilder {
             Err(status)
         }
     }
+
+    pub fn empty(&self) -> bool {
+        self.path_commands.len() == 0
+    }
 }
 
 #[cfg(test)]
